@@ -2,7 +2,7 @@ package WebService::MinFraud::Record::Country;
 
 use Moo;
 
-our $VERSION = '0.001001';
+our $VERSION = '0.001002';
 
 use WebService::MinFraud::Types qw( Bool BoolCoercion );
 
@@ -16,8 +16,21 @@ has is_high_risk => (
 );
 
 1;
+
+# ABSTRACT: Contains data for the country record associated with an IP address
+
 __END__
 
+=pod
+
+=head1 NAME
+
+WebService::MinFraud::Record::Country - Contains data for the country record associated with an IP address
+
+=head1 VERSION
+
+version 0.001002
+
 =head1 SYNOPSIS
 
   use 5.010;
@@ -55,3 +68,16 @@ The following predicate methods are available, which return true if the related
 data was present in the response body, false if otherwise:
 
 =head2 has_is_high_risk
+
+=head1 AUTHOR
+
+Mateu Hunter <mhunter@maxmind.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by MaxMind, Inc..
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
