@@ -2,7 +2,7 @@ package WebService::MinFraud::Record::Warning;
 
 use Moo;
 
-our $VERSION = '0.001001';
+our $VERSION = '0.001002';
 
 use Types::Standard qw( ArrayRef Str );
 
@@ -25,7 +25,7 @@ has input => (
 
 1;
 
-# ABSTRACT: Contains data for the warning record returned from a web service query
+# ABSTRACT: A warning record returned from a web service query
 
 __END__
 
@@ -33,11 +33,11 @@ __END__
 
 =head1 NAME
 
-WebService::MinFraud::Record::Warning - Contains data for the warning record returned from a web service query
+WebService::MinFraud::Record::Warning - A warning record returned from a web service query
 
 =head1 VERSION
 
-version 0.001001
+version 0.001002
 
 =head1 SYNOPSIS
 
@@ -50,12 +50,15 @@ version 0.001001
   );
   my $request = { device => { ip_address => '24.24.24.24'} };
   my $insights = $client->insights( $request );
-  my $warnings = $insights->warning;
-  say $warnings->warning;
+  foreach my $warning_object (@{$insights->warnings}) {
+        say "WARNING CODE: ", $warning_object->code;
+        say "WARNING MESSAGE: ", $warning_object->warning;
+        say "WARNING INPUT PATH: ", join ' / ', @{$warning_object->input};
+  }
 
 =head1 DESCRIPTION
 
-This class contains the MaxMind warning (if any) from a web service query.
+This class represents a MaxMind warning (if any) from a web service query.
 
 =head1 METHODS
 
